<div align="center">
  <a href="https://encore.dev" alt="encore"><img width="189px" src="https://encore.dev/assets/img/logo.svg"></a>
  <h3><a href="https://encore.dev">Encore – The Backend Development Engine</a></h3>
</div>
Encore makes it incredibly simple to create distributed systems, backend services and APIs. While still deploying to your own cloud account, Encore helps you escape the maze of cloud complexity:</br>

* No endless repetition of boilerplate

* No infrastructure to worry about

* No reinventing the wheel

Start building with a fantastic flow-state experience that unlocks your creative potential. <br/>All of this is freely available, based on the Open Source Encore Go Framework.
<br/><br/>

**🏁 Get started in minutes and check out the documentation: [encore.dev/docs](https://encore.dev/docs/quick-start)**

**⭐ If you find Encore interesting, please consider starring this repository to help spread the word.**

## Key features

* **[No Boilerplate](https://encore.dev/docs/develop/services-and-apis):** Set up a production ready backend application in minutes. Define services, API endpoints, and call APIs with a single line of Go code.

* **[Databases Made Simple](https://encore.dev/docs/concepts/databases):** Define the schema and then start querying. Encore takes care of provisioning, migrations, connections and passwords.

* **[Distributed Tracing](https://encore.dev/docs/observability/tracing):** Your application is automatically instrumented for excellent observability.
  Automatically capture information about API calls, goroutines, HTTP requests,
  database queries, and more. Works for both local development and production.

* **[Infrastructure Provisioning](https://encore.dev/docs/deploy/infra):** Encore understands how your application works,
  and provisions and manages your cloud infrastructure. Works with all the major cloud providers using your own account (AWS/Azure/GCP)
  and for local development.
  
* **[Preview Environments](https://encore.dev/docs/deploy/platform):** Every pull request becomes an isolated test environment. Collaborate and iterate faster than ever.
  
* **[Simple Secrets](https://encore.dev/docs/develop/secrets):** It's never been this easy to store and securely use secrets and API keys. Define secrets in your code like any other variable, Encore takes care of the rest.

* **[Automated API Documentation](https://encore.dev/docs/develop/api-docs):** Encore parses your source code to understand the request/response
  schemas for all your APIs, and automatically generates high-quality, interactive
  API Documentation for you.
  
* **[Generate Frontend Clients](https://encore.dev/docs/how-to/integrate-frontend):**  Automatically generate type-safe, documented clients for your frontends.

## Getting started

To start using Encore, follow our simple [Quick Start Guide](https://encore.dev/docs/quick-start).

## Screenshots

### Simple Cloud Environments

<img src="https://encore.dev/assets/github/environments.png" alt="Simple Cloud Environments" width=50% height=50%>

### Automatic Infrastructure Provisioning

<img src="https://encore.dev/assets/github/infrastructure.png" alt="Automatic Infrastructure Provisioning" width=50% height=50%>

### Distributed Tracing

<img src="https://encore.dev/assets/github/tracing.png" alt="Distributed Tracing" width=50% height=50%>

### Automated API Documentation

<img src="https://encore.dev/assets/github/documentation.png" alt="Automated API Documentation" width=50% height=50%>

### Native Cron Jobs

<img src="https://encore.dev/assets/github/cronjobs.png" alt="Native Cron Jobs" width=50% height=50%>

## Contributing to Encore and building from source

See [CONTRIBUTING.md](CONTRIBUTING.md).

## Frequently Asked Questions (FAQ)

#### Who's behind Encore?

Encore was founded by long-time backend engineers from Spotify, Google and Monzo with over 50 years collective experience. We’ve lived through the challenges of building complex distributed systems with thousands of services, and scaling to hundreds of millions of users.

Encore grew out of these experiences and is a solution to the frustrations that came with them: unnecessary crippling complexity and constant repetition of undifferentiated work that suffocates developer’s creativity. With Encore, we want to set developers free to achieve their creative potential.

#### Who is Encore for?

For individual developers building for the cloud, Encore provides a radically improved experience. With Encore you’re able to stay in the flowstate and experience the joy and creativity of building.

For startup teams who need to build a scalable backend to support the growth of their product, Encore lets them get up and running in the cloud within minutes. It lets them focus on solving for the needs of their users, instead of spending most of their time re-solving the everyday challenges of building distributed systems in the cloud.

For teams in mature organizations that want to focus on innovating and building new features, Encore lets them stop spending time on operations and onboarding new team members. Using Encore for new feature development is easy, just spin up a new backend service in a few minutes.

#### How is Encore different?

Encore is the only tool that understands what you’re building. The Encore framework, coupled with static analysis, lets Encore deeply understand the application you’re building. This enables the platform to provide a unique developer experience that helps you stay in the flowstate as you’re building.

Unlike many tools that aim to only make cloud deployment easier, Encore is not a cloud hosting provider. With Encore, you can use your own cloud account with all the major cloud providers: AWS/Azure/GCP. This means you’re in control of your data and can maintain your trust relationship with your cloud provider. You can also use Encore's development cloud for free, with pretty generous "fair use" limits. 

#### Why is the framework integrated with cloud hosting?

We've found that to meaningfully improve the developer experience, you have to operate across the full stack. Unless you understand how an application is deployed, there are a large number of things in the development process that you can't simplify. That's why so many other developer tools have such a limited impact. With Encore, we're bravely rethinking the developer experience in a much more significant way.

## Get Involved
We rely on your contributions and feedback to improve Encore.
We love hearing about your experiences using Encore, and about what may be unclear and we can do a better job explaining.

* ⭐ Star this repository to help spread the word.
* Join the most pioneering developer community on [Slack](https://encore.dev/slack).
* Follow us on [Twitter](https://twitter.com/encoredotdev).
* Send us feedback or ask questions via [email](mailto:hello@encore.dev).
* Leave feedback on our [Public Roadmap](https://encore.dev/roadmap).
* [Book a session](https://calendly.com/encoreandre/encore-office-hours) to speak with us directly.
